pub struct PromiseCapability<'a> { /* private fields */ }Expand description
A promise capability encapsulates a promise, adding methods that are capable of resolving or rejecting that promise.
NOTE: In the spec, promise capability records contain an object that is usable as a promise, together with its resolve and reject functions. In our current implementation, we only ever support built-in promises, and not other promise-like objects (e.g. we don’t support Promise subclasses), and for that we don’t need to store resolve and reject functions, we can create them only when needed.
The must_be_unresolved boolean is used to map the AlreadyResolved state
of a pair of resolve/reject functions with the promise state. If
must_be_unresolved is false, the promise counts as already resolved if its
state is Fulfilled or Rejected. If true, it also counts as already resolved
if it’s Pending but is_resolved is set to true.
Implementations
Sourceimpl<'a> PromiseCapability<'a>
impl<'a> PromiseCapability<'a>
Sourcepub fn new(agent: &mut Agent, gc: NoGcScope<'a, '_>) -> Self
pub fn new(agent: &mut Agent, gc: NoGcScope<'a, '_>) -> Self
27.2.1.5 NewPromiseCapability ( C )
Create a new PromiseCapability
NOTE: Our implementation doesn’t take C as a parameter, since we don’t yet support promise subclassing.
Sourcepub fn from_promise(promise: Promise<'a>, must_be_unresolved: bool) -> Self
pub fn from_promise(promise: Promise<'a>, must_be_unresolved: bool) -> Self
Recreate a PromiseCapability from its associated Promise and the
must_be_resolved boolean value.
Sourcepub fn resolve(
self,
agent: &mut Agent,
resolution: Value<'_>,
gc: GcScope<'_, '_>,
)
pub fn resolve( self, agent: &mut Agent, resolution: Value<'_>, gc: GcScope<'_, '_>, )
27.2.1.3.2 Promise Resolve Functions
Resolve the associated Promise with a given value. Ignored if the
Promise is already resolved.
Sourcepub fn try_resolve<'gc>(
&self,
agent: &mut Agent,
resolution: Value<'_>,
gc: NoGcScope<'gc, '_>,
) -> TryResult<'gc, ()>
pub fn try_resolve<'gc>( &self, agent: &mut Agent, resolution: Value<'_>, gc: NoGcScope<'gc, '_>, ) -> TryResult<'gc, ()>
27.2.1.3.2 Promise Resolve Functions
Try resolve the associated Promise with a given value. Fails if
resolving would require calling into user-code. Ignored if the
Promise is already resolved.