pub struct PropertyDescriptor<'a> {
pub value: Option<Value<'a>>,
pub writable: Option<bool>,
pub get: Option<Option<Function<'a>>>,
pub set: Option<Option<Function<'a>>>,
pub enumerable: Option<bool>,
pub configurable: Option<bool>,
}Expand description
Fields
value: Option<Value<'a>>[[Value]]
writable: Option<bool>[[Writable]]
get: Option<Option<Function<'a>>>[[Get]]
Note: double-Option because these fields can be set explicitly undefined to unset them.
set: Option<Option<Function<'a>>>[[Set]]
Note: double-Option because these fields can be set explicitly undefined to unset them.
enumerable: Option<bool>[[Enumerable]]
configurable: Option<bool>[[Configurable]]
Implementations
Sourceimpl<'a> PropertyDescriptor<'a>
impl<'a> PropertyDescriptor<'a>
Sourcepub fn new_data_descriptor(value: impl Into<Value<'a>>) -> Self
pub fn new_data_descriptor(value: impl Into<Value<'a>>) -> Self
Creates a new data descriptor from a Value.
Data descriptors are writable, enumerable, and configurable.
Sourcepub fn non_enumerable_data_descriptor(value: impl Into<Value<'a>>) -> Self
pub fn non_enumerable_data_descriptor(value: impl Into<Value<'a>>) -> Self
Creates a new non-enumerable data descriptor from a Value.
Sourcepub fn new_prototype_method_descriptor(
function: impl Into<Function<'a>>,
) -> Self
pub fn new_prototype_method_descriptor( function: impl Into<Function<'a>>, ) -> Self
Creates a new non-enumerable data descriptor from a Function.
Sourcepub fn is_accessor_descriptor(&self) -> bool
pub fn is_accessor_descriptor(&self) -> bool
Sourcepub fn is_data_descriptor(&self) -> bool
pub fn is_data_descriptor(&self) -> bool
Sourcepub fn is_generic_descriptor(&self) -> bool
pub fn is_generic_descriptor(&self) -> bool
Sourcepub fn from_property_descriptor(
desc: Option<Self>,
agent: &mut Agent,
gc: NoGcScope<'a, '_>,
) -> Option<OrdinaryObject<'a>>
pub fn from_property_descriptor( desc: Option<Self>, agent: &mut Agent, gc: NoGcScope<'a, '_>, ) -> Option<OrdinaryObject<'a>>
6.2.6.4 FromPropertyDescriptor ( Desc )
The abstract operation FromPropertyDescriptor takes argument Desc (a Property Descriptor or undefined) and returns an Object or undefined.
Sourcepub fn to_property_descriptor(
agent: &mut Agent,
obj: Value<'_>,
gc: GcScope<'a, '_>,
) -> JsResult<'a, Self>
pub fn to_property_descriptor( agent: &mut Agent, obj: Value<'_>, gc: GcScope<'a, '_>, ) -> JsResult<'a, Self>
6.2.6.5 ToPropertyDescriptor ( Obj )
The abstract operation ToPropertyDescriptor takes argument Obj (an ECMAScript language value) and returns either a normal completion containing a Property Descriptor or a throw completion.
Sourcepub fn is_fully_populated(&self) -> bool
pub fn is_fully_populated(&self) -> bool
Returns true if this property descriptor has been fully populated with
enumerable and configurable bits, and either a value and a writable bit
OR at least a getter or setter function.
Sourcepub fn has_fields(&self) -> bool
pub fn has_fields(&self) -> bool
Returns true if this property descriptor has any fields populated.