SmallInteger

Struct SmallInteger 

pub struct SmallInteger { /* private fields */ }
6.1.6.1 The Number Type

Stack-allocated integer Number data. Internally, the value is a 54-bit signed integer stored in 56 bits, filling in the entire safe integer range.

Implementations

Source

impl SmallInteger

pub const MIN: i64

Minimum value that can be represented as a SmallInteger.

This corresponds with Number.MIN_SAFE_INTEGER.

pub const MAX: i64

Maximum value that can be represented as a SmallInteger.

This corresponds with Number.MAX_SAFE_INTEGER.

pub const fn into_i64(self) -> i64

Returns the contained value as an i64.

pub const fn zero() -> Self

Returns the 0 value.