WeakRef

Struct WeakRef 

pub struct WeakRef<'a>(/* private fields */);
26.1 WeakRef Objects

A WeakRef is an object that is used to refer to a target object or symbol without preserving it from garbage collection. WeakRefs can be dereferenced to allow access to the target value, if the target hasn’t been reclaimed by garbage collection.