TryResult

Type Alias TryResult 

pub type TryResult<'a, T> = ControlFlow<TryError<'a>, T>;
Result of methods that are not allowed to call JavaScript or perform garbage collection.

Aliased Type

pub enum TryResult<'a, T> {
    Continue(T),
    Break(TryError<'a>),
}

Variants

1.55.0

Continue(T)

Move on to the next phase of the operation as normal.

1.55.0

Break(TryError<'a>)

Exit the operation without running subsequent phases.