pub type TryResult<'a, T> = ControlFlow<TryError<'a>, T>;Expand description
Result of methods that are not allowed to call JavaScript or perform garbage collection.
Aliased Type
pub enum TryResult<'a, T> {
Continue(T),
Break(TryError<'a>),
}Variants
Continue(T)
Move on to the next phase of the operation as normal.
Break(TryError<'a>)
Exit the operation without running subsequent phases.