#[repr(u8)]pub enum Primitive<'a> {
Undefined = 1,
Null = 2,
Boolean(bool),
String(HeapString<'a>),
SmallString(SmallString),
Symbol(Symbol<'a>),
Number(HeapNumber<'a>),
Integer(SmallInteger),
SmallF64(SmallF64),
BigInt(HeapBigInt<'a>),
SmallBigInt(SmallBigInt),
}Variants
Undefined = 1
Null = 2
Boolean(bool)
String(HeapString<'a>)
6.1.4 The String Type
UTF-8 string on the heap. Accessing the data must be done through the Agent. ECMAScript specification compliant UTF-16 indexing is implemented through an index mapping.
SmallString(SmallString)
6.1.4 The String Type
7-byte UTF-8 string on the stack. End of the string is determined by the first 0xFF byte in the data. UTF-16 indexing is calculated on demand from the data.
Symbol(Symbol<'a>)
Number(HeapNumber<'a>)
6.1.6.1 The Number Type
f64 on the heap. Accessing the data must be done through the Agent.
Integer(SmallInteger)
6.1.6.1 The Number Type
53-bit signed integer on the stack.
SmallF64(SmallF64)
6.1.6.1 The Number Type
56-bit f64 on the stack. The missing byte is a zero least significant byte.
BigInt(HeapBigInt<'a>)
6.1.6.2 The BigInt Type
Unlimited size integer data on the heap. Accessing the data must be done through the Agent.
SmallBigInt(SmallBigInt)
6.1.6.2 The BigInt Type
56-bit signed integer on the stack.
Implementations